@@ -9,27 +9,20 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Borrar",
+    "Select all" : "Seleccionar todo",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva ",
-    "Grid view" : "Vista de cuadrícula",
-    "List view" : "Vista de lista",
-    "Select all" : "Seleccionar todo",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "All bookmarks" : "Todos los marcadores",
     "Recent" : "Reciente",
-    "Add a bookmark" : "Agregar un marcador",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Recently added" : "Agregado recientemente",
-    "Alphabetically" : "Alfabéticamente",
-    "Last modified" : "Última modificación",
     "Bookmarklet" : "Marcador a código ",
     "Clear data" : "Borrar datos",
     "Title" : "Título",
     "Link" : "Liga",
     "Tags" : "Etiquetas",
-    "Attachments" : "Adjuntos",
     "Notes" : "Notas",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
@@ -37,8 +30,8 @@ OC.L10N.register(
     "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
     "Link copied" : "Vinculo copiado",
-    "Select" : "Seleccionar",
     "Privacy" : "Privacidad",
+    "Add a bookmark" : "Agregar un marcador",
     "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
