@@ -5,25 +5,19 @@ OC.L10N.register(
     "Rename" : "Преименувај",
     "Move" : "Премести",
     "Delete" : "Избриши",
+    "Select all" : "Избери се",
     "New" : "Ново",
     "New folder" : "Нова папка",
-    "Grid view" : "Мрежа",
-    "List view" : "Листа",
-    "RSS Feed of current view" : "RSS канал од моменталниот поглед",
-    "Select all" : "Избери се",
+    "RSS feed copied" : "RSS канал копиран",
     "Submit" : "Испрати",
     "Cancel" : "Откажи",
     "Recent" : "Неодамнешни",
     "Import" : "Увези",
     "Export" : "Извези",
-    "Recently added" : "Скоро додадени",
-    "Alphabetically" : "Азбучно",
-    "Last modified" : "Скоро изменети",
     "Clear data" : "Исчисти податоци",
     "Title" : "Наслов",
     "Link" : "Линк",
     "Tags" : "Ознаки",
-    "Attachments" : "Прилози",
     "Notes" : "Белешки",
     "Owner" : "Сопственик",
     "Sharing" : "Споделување",
@@ -34,8 +28,6 @@ OC.L10N.register(
     "Allow editing" : "Овозможи уредување",
     "Remove share" : "Отстрани споделување",
     "Link copied" : "Линкот е копиран",
-    "RSS feed copied" : "RSS канал копиран",
-    "Select" : "Select",
     "Privacy" : "Приватност",
     "Failed to save settings" : "Неуспешно зачувување на параметрите",
     "Folder" : "Папка",
